@@ -224,15 +224,21 @@ def retailer_versions(ctx, notify, delay):
 
 @api.command()
 @click.argument('retailer')
+@click.option('--v2', is_flag=True, show_default=True, default=False, help="Use models v2 API")
 @pass_rebotics_context
-def models(ctx, retailer):
+def models(ctx, retailer, v2):
     """
         Fetch and display retailer NN configurations
     """
     try:
-        ctx.format_result(
-            ctx.provider.get_retailer_tf_models(codename=retailer)
-        )
+        if v2:
+            ctx.format_result(
+                ctx.provider.get_models_conf_v2(codename=retailer)
+            )
+        else:
+            ctx.format_result(
+                ctx.provider.get_retailer_tf_models(codename=retailer)
+            )
     except Exception as exc:
         raise click.ClickException(str(exc))
 
