@@ -27,6 +27,23 @@ class AdminProvider(ReboticsBaseProvider):
     def get_retailer_tf_models_by_codename(self, codename, **kwargs):
         return self.session.get(codename=codename)
 
+    @remote_service('nn_models/v2/models/')
+    def get_models_v2(self):
+        assert self.is_retailer_identifier_used()
+        return self.session.get()
+
+    @remote_service('nn_models/v2/models/{codename}/')
+    def get_models_v2_by_codename(self, codename):
+        assert not self.is_retailer_identifier_used()
+        return self.session.get(codename=codename)
+
+    def get_models_conf_v2(self, codename=None, **kwargs):
+        if codename is None:
+            # check if the configuration is using retailer-auth
+            return self.get_models_v2()
+        else:
+            return self.get_models_v2_by_codename(codename)
+
     @remote_service('/retailers/host/')
     def get_retailer(self, retailer_codename, **kwargs):
         response = self.session.post(data={
