@@ -3,11 +3,16 @@ import json
 import six
 
 from rebotics_sdk.providers.utils import hash_file, accept_file
-from .base import ReboticsBaseProvider, remote_service, PageResult
+from .base import ReboticsBaseProvider, remote_service, PageResult, UniqueRequestProxy
 from ..advanced.flows import FeatureVectorFlow
 
 
 class RetailerProvider(ReboticsBaseProvider):
+    proxy_class = UniqueRequestProxy
+    proxy_config = {
+        'request_uid_header_name': 'REB-CLIENT-REQUEST-UID'
+    }
+
     @remote_service('/api/v4/')
     def api_v4_root(self, **kwargs):
         return self.session.get()
@@ -70,7 +75,9 @@ class RetailerProvider(ReboticsBaseProvider):
             'force': force
         })
 
-    @remote_service('/api/v4/processing/actions/')
+    @remote_service(
+        '/api/v4/processing/actions/',
+        request_uid_value=lambda **kwargs: kwargs['json'].pop('_request_uid', None))
     def create_processing_action(
         self, store_id, files, input_type='image',
         store_planogram=None,
